package unittest

import (
	"database/sql"
	"fmt"
	"testing"
	"xugugodriver/go_unit/unittest"
)

func TestDbExec_Insert_Binary_NULL(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1001
	testdb.Exec("delete GO_UNIT_BINARY_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_BINARY_DEAL VALUES(?,?,?,?)", rowid, nil, nil, nil)
	var equalsql = fmt.Sprintf("select count(*) from GO_UNIT_BINARY_DEAL where id = %d and B1 IS NULL and B2 IS NULL and B3 IS NULL;", rowid)
	var equalrow = testdb.QueryRow(equalsql)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Binary_NULL FAIL.")
	}
	testdb.Close()
}

// 可以插入不可以查询, b1导致了不能查询。
func TestDbExec_Insert_Binary_0(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1002
	b1 := []byte{0}
	b2 := []byte{0}
	b3 := []byte{0}

	testdb.Exec("delete GO_UNIT_BINARY_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_BINARY_DEAL VALUES(?,?,?,?)", rowid, b1, b2, b3)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_BINARY_DEAL where id = ? and B1 = ? and B2 = ? and B3 = ?;", rowid, b1, b2, b3)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Binary_0 FAIL.")
	}
	testdb.Close()
}

// 可以插入不可以查询, b1导致了不能查询。
func TestDbExec_Insert_Binary_byte(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1003
	b1 := []byte{1}
	b2 := []byte{0, 0, 1, 1, 0, 1, 1}
	b3 := []byte{1, 0, 0, 0, 0, 1, 0, 1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 1, 1, 0, 1, 1, 1}

	testdb.Exec("delete GO_UNIT_BINARY_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_BINARY_DEAL VALUES(?,?,?,?)", rowid, b1, b2, b3)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_BINARY_DEAL where id = ? and B1 = ? and B2 = ? and B3 = ?;", rowid, b1, b2, b3)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Blob_0 FAIL.")
	}
	testdb.Close()
}
