package unittest

import (
	"database/sql"
	"fmt"
	"testing"
	"xugugodriver/go_unit/unittest"

)

func TestDbExec_Insert_Blob_NULL(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1001
	testdb.Exec("delete GO_UNIT_BLOB_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_BLOB_DEAL VALUES(?,?)", rowid, nil)
	var equalsql = fmt.Sprintf("select count(*) from GO_UNIT_BLOB_DEAL where id = %d and B1 IS NULL;", rowid)
	var equalrow = testdb.QueryRow(equalsql)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Blob_NULL FAIL.")
	}
	testdb.Close()
}

// database/sql defaultCheckNamedValue 会把byte转int64 造成类型不符合
func TestDbExec_Insert_Blob_0(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1002
	b1 := []byte{0}
	testdb.Exec("delete GO_UNIT_BLOB_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_BLOB_DEAL VALUES(?,?)", rowid, b1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_BLOB_DEAL where id = ? and B1 = ?;", rowid, b1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Blob_0 FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Blob_number(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1003
	b1 := []byte{1, 2, 3, 4, 5, 6, 7, 8, 9}
	testdb.Exec("delete GO_UNIT_BLOB_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_BLOB_DEAL VALUES(?,?)", rowid, b1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_BLOB_DEAL where id = ? and B1 = ?;", rowid, b1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Blob_0 FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Blob_char(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1004
	b1 := []byte{'A', 'B', 'C', 'D', 'E', 'F', 'A', 'B', 'C', 'D', 'E', 'F'}
	testdb.Exec("delete GO_UNIT_BLOB_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_BLOB_DEAL VALUES(?,?)", rowid, b1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_BLOB_DEAL where id = ? and B1 = ?;", rowid, b1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Blob_char FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Blob_big(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1005
	var blob_size = 1024 * 1024 * 50
	b1 := make([]byte, blob_size)
	for i := 0; i < blob_size; i += 1 {
		b1[i] = byte(i)
	}
	testdb.Exec("delete GO_UNIT_BLOB_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_BLOB_DEAL VALUES(?,?)", rowid, b1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_BLOB_DEAL where id = ? and B1 = ?;", rowid, b1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Blob_0 FAIL.")
	}
	testdb.Close()
}
