package unittest

import (
	"database/sql"
	"fmt"
	"strings"
	"testing"
	"xugugodriver/go_unit/unittest"
)

func TestDbExec_Insert_Char_NULL(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1001
	testdb.Exec("delete GO_UNIT_CHAR_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_CHAR_DEAL VALUES(?,?,?,?)", rowid, nil, nil, nil)
	var equalsql = fmt.Sprintf("select count(*) from GO_UNIT_CHAR_DEAL where id = %d and CH IS NULL AND CHN IS NULL AND VAR IS NULL;", rowid)
	var equalrow = testdb.QueryRow(equalsql)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Char_EmptyString(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1002
	var ch = ""
	var chn = ""
	var varch = ""
	testdb.Exec("delete GO_UNIT_CHAR_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_CHAR_DEAL VALUES(?,?,?,?)", rowid, ch, chn, varch)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_CHAR_DEAL where id = ? and CH = ? AND CHN = ? AND VAR = ?;", rowid, ch, chn, varch)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Char_Blank(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1003
	var ch = " "
	var chn = " "
	var varch = " "
	testdb.Exec("delete GO_UNIT_CHAR_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_CHAR_DEAL VALUES(?,?,?,?)", rowid, ch, chn, varch)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_CHAR_DEAL where id = ? and CH = ? AND CHN = ? AND VAR = ?;", rowid, ch, chn, varch)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Char_English(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1004
	var ch = "A"
	var chn = "ABC"
	var varch = "ABC"
	testdb.Exec("delete GO_UNIT_CHAR_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_CHAR_DEAL VALUES(?,?,?,?)", rowid, ch, chn, varch)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_CHAR_DEAL where id = ? and CH = ? AND CHN = ? AND VAR = ?;", rowid, ch, chn, varch)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Char_Symbol(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1005
	var ch = "\""
	var chn = "\"!@#$%^&*()_+~"
	var varch = "\"!@#$%^&*()_+~');"
	testdb.Exec("delete GO_UNIT_CHAR_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_CHAR_DEAL VALUES(?,?,?,?)", rowid, ch, chn, varch)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_CHAR_DEAL where id = ? and CH = ? AND CHN = ? AND VAR = ?;", rowid, ch, chn, varch)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Char_Chinese(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1006
	var ch = "中"
	var chn = "中文"
	var varch = "中文数据"
	testdb.Exec("delete GO_UNIT_CHAR_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_CHAR_DEAL VALUES(?,?,?,?)", rowid, ch, chn, varch)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_CHAR_DEAL where id = ? and CH = ? AND CHN = ? AND VAR = ?;", rowid, ch, chn, varch)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Char_LongEnglish(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1007
	var ch = "1"
	var builder strings.Builder
	for i := 0; i < 3; i++ {
		builder.WriteString("0123456789")
	}
	var chn = builder.String()
	builder.Reset()
	for i := 0; i < 500; i++ {
		builder.WriteString("0123456789")
	}
	var varch = builder.String()
	testdb.Exec("delete GO_UNIT_CHAR_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_CHAR_DEAL VALUES(?,?,?,?)", rowid, ch, chn, varch)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_CHAR_DEAL where id = ? and CH = ? AND CHN = ? AND VAR = ?;", rowid, ch, chn, varch)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Char_LongChinese(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1007
	var ch = "1"
	var builder strings.Builder
	for i := 0; i < 3; i++ {
		builder.WriteString("零一二三四五六七八九")
	}
	var chn = builder.String()
	builder.Reset()
	for i := 0; i < 500; i++ {
		builder.WriteString("零一二三四五六七八九")
	}
	var varch = builder.String()
	testdb.Exec("delete GO_UNIT_CHAR_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_CHAR_DEAL VALUES(?,?,?,?)", rowid, ch, chn, varch)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_CHAR_DEAL where id = ? and CH = ? AND CHN = ? AND VAR = ?;", rowid, ch, chn, varch)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}
