package unittest

import (
	"database/sql"
	"fmt"
	"xugugodriver/go_unit/unittest"

	"strings"
	"testing"
)

func TestDbExec_Insert_Clob_NULL(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1001
	testdb.Exec("delete GO_UNIT_CLOB_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_CLOB_DEAL VALUES(?,?)", rowid, nil, nil, nil)
	var equalsql = fmt.Sprintf("select count(*) from GO_UNIT_CLOB_DEAL where id = %d and C1 IS NULL;", rowid)
	var equalrow = testdb.QueryRow(equalsql)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Clob_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Clob_0(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1002
	var c1 = ""
	testdb.Exec("delete GO_UNIT_CLOB_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_CLOB_DEAL VALUES(?,?)", rowid, c1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_CLOB_DEAL where id = ? and C1 = ?;", rowid, c1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Clob_0 FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Clob_number(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1003
	var c1 = "123456789"
	testdb.Exec("delete GO_UNIT_CLOB_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_CLOB_DEAL VALUES(?,?)", rowid, c1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_CLOB_DEAL where id = ? and C1 = ?;", rowid, c1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Clob_number FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Clob_char(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1004
	var c1 = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
	testdb.Exec("delete GO_UNIT_CLOB_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_CLOB_DEAL VALUES(?,?)", rowid, c1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_CLOB_DEAL where id = ? and C1 = ?;", rowid, c1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Clob_char FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Clob_symbol(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1005
	var c1 = "!@#$%^&*()_+-={}[]''\""
	testdb.Exec("delete GO_UNIT_CLOB_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_CLOB_DEAL VALUES(?,?)", rowid, c1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_CLOB_DEAL where id = ? and C1 = ?;", rowid, c1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Clob_symbol FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Clob_chinese(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1006
	var c1 = "中文数据测试一二三四五六七八九十"
	testdb.Exec("delete GO_UNIT_CLOB_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_CLOB_DEAL VALUES(?,?)", rowid, c1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_CLOB_DEAL where id = ? and C1 = ?;", rowid, c1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Clob_symbol FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Clob_bigchar(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1007
	var builder strings.Builder
	for i := 0; i < 5000; i++ {
		builder.WriteString("中文数据测试一二三四五六七八九十")
	}
	var c1 = builder.String()
	testdb.Exec("delete GO_UNIT_CLOB_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_CLOB_DEAL VALUES(?,?)", rowid, c1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_CLOB_DEAL where id = ? and C1 = ?;", rowid, c1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Clob_symbol FAIL.")
	}
	testdb.Close()
}
