package unittest

import (
	"database/sql"
	"fmt"
	"xugugodriver/go_unit/unittest"

	"testing"
	"time"
)

func TestDbExec_Insert_Date_NULL(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1001
	testdb.Exec("delete GO_UNIT_DATE_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_DATE_DEAL VALUES(?,?,?,?,?,?,?,?)", rowid, nil, nil, nil, nil, nil, nil, nil)
	var equalsql = fmt.Sprintf("select count(*) from GO_UNIT_DATE_DEAL where id = %d and DT IS NULL AND TM IS NULL AND TMZ IS NULL AND DTTM IS NULL AND DTTMZ IS NULL AND TS IS NULL AND TSZ IS NULL;", rowid)
	var equalrow = testdb.QueryRow(equalsql)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Date_NULL FAIL.")
	}
	testdb.Close()
}

// 驱动time.Time 只会组装成YYYY-MM-DD HH:MM:SS的格式，DATE，time类型插入不进去。 需测试mysql
func TestDbExec_Insert_Date_TimeMin(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1002
	var dt, _ = time.Parse("2006-01-02", "0001-01-01")
	var tm, _ = time.Parse("15:04:05", "00:00:00")
	var tmz, _ = time.Parse("15:04:05", "00:00:00")
	var date, _ = time.Parse("2006-01-02 15:04:05", "0001-01-01 00:00:00")
	var datez, _ = time.Parse("2006-01-02 15:04:05", "0001-01-01 00:00:00")
	var ts, _ = time.Parse("2006-01-02 15:04:05", "0001-01-01 00:00:00")
	var tsz, _ = time.Parse("2006-01-02 15:04:05", "0001-01-01 00:00:00")
	testdb.Exec("delete GO_UNIT_DATE_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_DATE_DEAL VALUES(?,?,?,?,?,?,?,?)", rowid, dt, tm, tmz, date, datez, ts, tsz)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_DATE_DEAL where id = ? and DT = ? AND TM = ? AND TMZ = ? AND DTTM = ? AND DTTMZ = ? AND TS = ? AND TSZ = ?;",
		rowid, dt, tm, tmz, date, datez, ts, tsz)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Date_TimeMin FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Date_TimeMax(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1003
	var dt, _ = time.Parse("2006-01-02 15:04:05", "9999-12-31 23:59:59.999")
	var tm, _ = time.Parse("2006-01-02 15:04:05", "9999-12-31 23:59:59.999")
	var tmz, _ = time.Parse("2006-01-02 15:04:05", "9999-12-31 23:59:59.999")
	var date, _ = time.Parse("2006-01-02 15:04:05", "9999-12-31 23:59:59.999")
	var datez, _ = time.Parse("2006-01-02 15:04:05", "9999-12-31 23:59:59.999")
	var ts, _ = time.Parse("2006-01-02 15:04:05", "9999-12-31 23:59:59.999")
	var tsz, _ = time.Parse("2006-01-02 15:04:05", "9999-12-31 23:59:59.999")
	testdb.Exec("delete GO_UNIT_DATE_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_DATE_DEAL VALUES(?,?,?,?,?,?,?,?)", rowid, dt, tm, tmz, date, datez, ts, tsz)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_DATE_DEAL where id = ? and DT = ? AND TM = ? AND TMZ = ? AND DTTM = ? AND DTTMZ = ? AND TS = ? AND TSZ = ?;",
		rowid, dt, tm, tmz, date, datez, ts, tsz)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Date_TimeMax FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Date_CharMin(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1004
	var dt = "0001-01-01"
	var tm = "00:00:00"
	var tmz = "00:00:00"
	var date = "0001-01-01 00:00:00"
	var datez = "0001-01-01 00:00:00"
	var ts = "0001-01-01 00:00:00"
	var tsz = "0001-01-01 00:00:00"
	testdb.Exec("delete GO_UNIT_DATE_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_DATE_DEAL VALUES(?,?,?,?,?,?,?,?)", rowid, dt, tm, tmz, date, datez, ts, tsz)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_DATE_DEAL where id = ? and DT = ? AND TM = ? AND TMZ = ? AND DTTM = ? AND DTTMZ = ? AND TS = ? AND TSZ = ?;",
		rowid, dt, tm, tmz, date, datez, ts, tsz)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Date_CharMin FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Date_CharMax(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1005
	var dt = "9999-12-31"
	var tm = "23:59:59.999"
	var tmz = "23:59:59.999"
	var date = "9999-12-31 23:59:59.999"
	var datez = "9999-12-31 23:59:59.999"
	var ts = "9999-12-31 23:59:59.999"
	var tsz = "9999-12-31 23:59:59.999"
	testdb.Exec("delete GO_UNIT_DATE_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_DATE_DEAL VALUES(?,?,?,?,?,?,?,?)", rowid, dt, tm, tmz, date, datez, ts, tsz)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_DATE_DEAL where id = ? and DT = ? AND TM = ? AND TMZ = ? AND DTTM = ? AND DTTMZ = ? AND TS = ? AND TSZ = ?;",
		rowid, dt, tm, tmz, date, datez, ts, tsz)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Date_CharMax FAIL.")
	}
	testdb.Close()
}
