package unittest

import (
	"database/sql"
	"fmt"
	"xugugodriver/go_unit/unittest"

	"testing"
)

func TestDbExec_Insert_Float_NULL(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1001
	testdb.Exec("delete GO_UNIT_FLOAT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_FLOAT_DEAL VALUES(?,?,?,?)", rowid, nil, nil, nil)
	var equalsql = fmt.Sprintf("select count(*) from GO_UNIT_FLOAT_DEAL where id = %d and F1 IS NULL AND D1 IS NULL AND NUM IS NULL;", rowid)
	var equalrow = testdb.QueryRow(equalsql)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Float_0(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1002
	var f1 = 0.0
	var d1 = 0.0
	var num = 0.0
	testdb.Exec("delete GO_UNIT_FLOAT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_FLOAT_DEAL VALUES(?,?,?,?)", rowid, f1, d1, num)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_FLOAT_DEAL where id = ? and f1 = ? AND d1 = ? AND num = ?;", rowid, f1, d1, num)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Float_1(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1003
	var f1 = 1.0
	var d1 = 1.0
	var num = 1.0
	testdb.Exec("delete GO_UNIT_FLOAT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_FLOAT_DEAL VALUES(?,?,?,?)", rowid, f1, d1, num)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_FLOAT_DEAL where id = ? and f1 = ? AND d1 = ? AND num = ?;", rowid, f1, d1, num)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Float_integerMax(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1004
	var f1 = 999999.0
	var d1 = 999999999999999.0
	var num = 999999.0
	testdb.Exec("delete GO_UNIT_FLOAT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_FLOAT_DEAL VALUES(?,?,?,?)", rowid, f1, d1, num)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_FLOAT_DEAL where id = ? and f1 = ? AND d1 = ? AND num = ?;", rowid, f1, d1, num)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Float_decimalMin(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1005
	var f1 = 0.0000000001
	var d1 = 0.0000000001
	var num = 0.000001
	testdb.Exec("delete GO_UNIT_FLOAT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_FLOAT_DEAL VALUES(?,?,?,?)", rowid, f1, d1, num)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_FLOAT_DEAL where id = ? and f1 = ? AND d1 = ? AND num = ?;", rowid, f1, d1, num)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Float_decimalMax(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1006
	var f1 = 0.99999
	var d1 = 0.9999999999
	var num = 0.999999
	testdb.Exec("delete GO_UNIT_FLOAT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_FLOAT_DEAL VALUES(?,?,?,?)", rowid, f1, d1, num)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_FLOAT_DEAL where id = ? and f1 = ? AND d1 = ? AND num = ?;", rowid, f1, d1, num)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Float_Minus1(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1007
	var f1 = -1.0
	var d1 = -1.0
	var num = -1.0
	testdb.Exec("delete GO_UNIT_FLOAT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_FLOAT_DEAL VALUES(?,?,?,?)", rowid, f1, d1, num)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_FLOAT_DEAL where id = ? and f1 = ? AND d1 = ? AND num = ?;", rowid, f1, d1, num)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Float_integerMin(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1008
	var f1 = -999999.0
	var d1 = -999999999999999.0
	var num = -999999.0
	testdb.Exec("delete GO_UNIT_FLOAT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_FLOAT_DEAL VALUES(?,?,?,?)", rowid, f1, d1, num)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_FLOAT_DEAL where id = ? and f1 = ? AND d1 = ? AND num = ?;", rowid, f1, d1, num)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Float_MinusDecimalMax(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1009
	var f1 = -0.0000000001
	var d1 = -0.0000000001
	var num = -0.000001
	testdb.Exec("delete GO_UNIT_FLOAT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_FLOAT_DEAL VALUES(?,?,?,?)", rowid, f1, d1, num)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_FLOAT_DEAL where id = ? and f1 = ? AND d1 = ? AND num = ?;", rowid, f1, d1, num)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Float_MinusDecimalMin(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1010
	var f1 = -0.99999
	var d1 = -0.9999999999
	var num = -0.999999
	testdb.Exec("delete GO_UNIT_FLOAT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_FLOAT_DEAL VALUES(?,?,?,?)", rowid, f1, d1, num)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_FLOAT_DEAL where id = ? and f1 = ? AND d1 = ? AND num = ?;", rowid, f1, d1, num)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}
