package unittest

import (
	"database/sql"
	"fmt"
	"testing"
	"xugugodriver/go_unit/unittest"
)

func TestDbExec_Insert_Int_NULL(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1001
	testdb.Exec("delete GO_UNIT_INT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_INT_DEAL VALUES(?,?,?,?,?)", rowid, nil, nil, nil, nil)
	var equalsql = fmt.Sprintf("select count(*) from GO_UNIT_INT_DEAL where id = %d and TINY IS NULL AND SMALL IS NULL AND INTE IS NULL AND BIG IS NULL;", rowid)
	var equalrow = testdb.QueryRow(equalsql)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Int_0(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1002
	var tiny = 0
	var small = 0
	var inte = 0
	var big = 0
	testdb.Exec("delete GO_UNIT_INT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_INT_DEAL VALUES(?,?,?,?,?)", rowid, tiny, small, inte, big)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_INT_DEAL where id = ? and TINY = ? AND SMALL = ? AND INTE = ? and BIG = ?;", rowid, tiny, small, inte, big)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Int_1(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1003
	var tiny = 1
	var small = 1
	var inte = 1
	var big = 1
	testdb.Exec("delete GO_UNIT_INT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_INT_DEAL VALUES(?,?,?,?,?)", rowid, tiny, small, inte, big)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_INT_DEAL where id = ? and TINY = ? AND SMALL = ? AND INTE = ? and BIG = ?;", rowid, tiny, small, inte, big)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Int_Minus1(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1004
	var tiny = -1
	var small = -1
	var inte = -1
	var big = -1
	testdb.Exec("delete GO_UNIT_INT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_INT_DEAL VALUES(?,?,?,?,?)", rowid, tiny, small, inte, big)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_INT_DEAL where id = ? and TINY = ? AND SMALL = ? AND INTE = ? and BIG = ?;", rowid, tiny, small, inte, big)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Int_Max(t *testing.T) {

	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1005
	var tiny = 127
	var small = 32767
	var inte = 2147483647
	var big = 9223372036854775807
	testdb.Exec("delete GO_UNIT_INT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_INT_DEAL VALUES(?,?,?,?,?)", rowid, tiny, small, inte, big)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_INT_DEAL where id = ? and TINY = ? AND SMALL = ? AND INTE = ? and BIG = ?;", rowid, tiny, small, inte, big)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Int_Min(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1006
	var tiny = -128
	var small = -32768
	var inte = -2147483648
	var big = -9223372036854775808
	testdb.Exec("delete GO_UNIT_INT_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_INT_DEAL VALUES(?,?,?,?,?)", rowid, tiny, small, inte, big)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_INT_DEAL where id = ? and TINY = ? AND SMALL = ? AND INTE = ? and BIG = ?;", rowid, tiny, small, inte, big)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Int_NULL FAIL.")
	}
	testdb.Close()
}
