package unittest

import (
	"database/sql"
	"fmt"
	"testing"
	"xugugodriver/go_unit/unittest"
)

func TestDbExec_Insert_Interval2_NULL(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1001
	testdb.Exec("delete GO_UNIT_INTERVAL2_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_INTERVAL2_DEAL VALUES(?,?,?,?,?,?,?,?)", rowid, nil, nil, nil, nil, nil, nil, nil)
	var equalsql = fmt.Sprintf("select count(*) from GO_UNIT_INTERVAL2_DEAL where id = %d and IY2M IS NULL AND ID2H IS NULL AND ID2M IS NULL AND ID2S IS NULL AND IH2M IS NULL AND IH2S IS NULL AND IM2S IS NULL;", rowid)
	var equalrow = testdb.QueryRow(equalsql)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Interval1_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Interval2_0(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1002
	var iytm = "0-0"
	var id2h = "0 0"
	var id2m = "0 0:0"
	var id2s = "0 0:0:0"
	var ihtm = "0:0"
	var ihts = "0:0:0"
	var imts = "0:0"
	testdb.Exec("delete GO_UNIT_INTERVAL2_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_INTERVAL2_DEAL VALUES(?,?,?,?,?,?,?,?)", rowid, iytm, id2h, id2m, id2s, ihtm, ihts, imts)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_INTERVAL2_DEAL where id = ? and iy2m = ? AND id2h = ? AND id2m = ? AND id2s = ? AND ih2m = ? AND ih2s = ? AND im2s = ?;",
		rowid, iytm, id2h, id2m, id2s, ihtm, ihts, imts)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Interval2_0 FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Interval2_Max(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1003
	var iytm = "9999-11"
	var id2h = "99999 23"
	var id2m = "99999 23:59"
	var id2s = "99999 23:59:59.999"
	var ihtm = "999999:59"
	var ihts = "9999999:59:59.999"
	var imts = "9999999:59.999"
	testdb.Exec("delete GO_UNIT_INTERVAL2_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_INTERVAL2_DEAL VALUES(?,?,?,?,?,?,?,?)", rowid, iytm, id2h, id2m, id2s, ihtm, ihts, imts)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_INTERVAL2_DEAL where id = ? and iy2m = ? AND id2h = ? AND id2m = ? AND id2s = ? AND ih2m = ? AND ih2s = ? AND im2s = ?;",
		rowid, iytm, id2h, id2m, id2s, ihtm, ihts, imts)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Interval2_0 FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Interval2_Min(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1004
	var iytm = "-9999-11"
	var id2h = "-99999 23"
	var id2m = "-99999 23:59"
	var id2s = "-99999 23:59:59.999"
	var ihtm = "-999999:59"
	var ihts = "-9999999:59:59.999"
	var imts = "-9999999:59.999"
	testdb.Exec("delete GO_UNIT_INTERVAL2_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_INTERVAL2_DEAL VALUES(?,?,?,?,?,?,?,?)", rowid, iytm, id2h, id2m, id2s, ihtm, ihts, imts)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_INTERVAL2_DEAL where id = ? and iy2m = ? AND id2h = ? AND id2m = ? AND id2s = ? AND ih2m = ? AND ih2s = ? AND im2s = ?;",
		rowid, iytm, id2h, id2m, id2s, ihtm, ihts, imts)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Interval2_0 FAIL.")
	}
	testdb.Close()
}
