package unittest

import (
	"database/sql"
	"fmt"
	"testing"
	"xugugodriver/go_unit/unittest"
)

func TestDbExec_Insert_Json_NULL(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1001
	testdb.Exec("delete GO_UNIT_JSON_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_JSON_DEAL VALUES(?,?)", rowid, nil)
	var equalsql = fmt.Sprintf("select count(*) from GO_UNIT_JSON_DEAL where id = %d and j1 IS NULL;", rowid)
	var equalrow = testdb.QueryRow(equalsql)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Guid_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Json_nullchar(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1002
	var j1 = "null"
	testdb.Exec("delete GO_UNIT_JSON_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_JSON_DEAL VALUES(?,?)", rowid, j1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_JSON_DEAL where id = ? and j1 = ?;", rowid, j1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Json_nullchar FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Json_truechar(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1003
	var j1 = "true"
	testdb.Exec("delete GO_UNIT_JSON_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_JSON_DEAL VALUES(?,?)", rowid, j1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_JSON_DEAL where id = ? and j1 = ?;", rowid, j1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Json_truechar FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Json_falsechar(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1004
	var j1 = "false"
	testdb.Exec("delete GO_UNIT_JSON_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_JSON_DEAL VALUES(?,?)", rowid, j1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_JSON_DEAL where id = ? and j1 = ?;", rowid, j1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Json_falsechar FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Json_1char(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1005
	var j1 = "1"
	testdb.Exec("delete GO_UNIT_JSON_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_JSON_DEAL VALUES(?,?)", rowid, j1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_JSON_DEAL where id = ? and j1 = ?;", rowid, j1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Json_1char FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Json_minus1char(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1006
	var j1 = "-1"
	testdb.Exec("delete GO_UNIT_JSON_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_JSON_DEAL VALUES(?,?)", rowid, j1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_JSON_DEAL where id = ? and j1 = ?;", rowid, j1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Json_minus1char FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Json_decimalchar(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1007
	var j1 = "0.01"
	testdb.Exec("delete GO_UNIT_JSON_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_JSON_DEAL VALUES(?,?)", rowid, j1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_JSON_DEAL where id = ? and j1 = ?;", rowid, j1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Json_decimalchar FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Json_chinese(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1008
	var j1 = "\"中文数据测试\""
	testdb.Exec("delete GO_UNIT_JSON_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_JSON_DEAL VALUES(?,?)", rowid, j1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_JSON_DEAL where id = ? and j1 = ?;", rowid, j1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Json_decimalchar FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Json_charlist(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1009
	var j1 = "[\"abc\", true, false, 1, 1.1, null]"
	testdb.Exec("delete GO_UNIT_JSON_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_JSON_DEAL VALUES(?,?)", rowid, j1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_JSON_DEAL where id = ? and j1 = ?;", rowid, j1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Json_decimalchar FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Json_chartuple(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1010
	var j1 = "{\"key1\": \"value\", \"key2\": true, \"key3\": false, \"key4\": 1, \"key5\": 1.1, \"key6\": null}"
	testdb.Exec("delete GO_UNIT_JSON_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_JSON_DEAL VALUES(?,?)", rowid, j1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_JSON_DEAL where id = ? and j1 = ?;", rowid, j1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Json_decimalchar FAIL.")
	}
	testdb.Close()
}
