package unittest

import (
	"database/sql"
	"fmt"
	"testing"
	"xugugodriver/go_unit/unittest"
)

func TestDbExec_Insert_Xml_NULL(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1001
	testdb.Exec("delete GO_UNIT_Xml_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_Xml_DEAL VALUES(?,?)", rowid, nil)
	var equalsql = fmt.Sprintf("select count(*) from GO_UNIT_Xml_DEAL where id = %d and x1 IS NULL;", rowid)
	var equalrow = testdb.QueryRow(equalsql)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Xml_NULL FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Xml_string(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1002
	var x1 = "<string>abc</string>"
	testdb.Exec("delete GO_UNIT_Xml_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_Xml_DEAL VALUES(?,?)", rowid, x1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_Xml_DEAL where id = ? and x1 = ?;", rowid, x1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Xml_string FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Xml_stringchinese(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1003
	var x1 = "<string>中文数据测试</string>"
	testdb.Exec("delete GO_UNIT_Xml_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_Xml_DEAL VALUES(?,?)", rowid, x1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_Xml_DEAL where id = ? and x1 = ?;", rowid, x1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Xml_stringchinese FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Xml_interger(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1004
	var x1 = "<int>11</int>"
	testdb.Exec("delete GO_UNIT_Xml_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_Xml_DEAL VALUES(?,?)", rowid, x1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_Xml_DEAL where id = ? and x1 = ?;", rowid, x1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Xml_interger FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Xml_double(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1005
	var x1 = "<double>11.1</double>"
	testdb.Exec("delete GO_UNIT_Xml_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_Xml_DEAL VALUES(?,?)", rowid, x1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_Xml_DEAL where id = ? and x1 = ?;", rowid, x1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Xml_interger FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Xml_true(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1006
	var x1 = "<bool>true</bool>"
	testdb.Exec("delete GO_UNIT_Xml_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_Xml_DEAL VALUES(?,?)", rowid, x1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_Xml_DEAL where id = ? and x1 = ?;", rowid, x1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Xml_interger FAIL.")
	}
	testdb.Close()
}

func TestDbExec_Insert_Xml_false(t *testing.T) {
	testdb, err := sql.Open("xugusql", unittest.Dsn)
	if err != nil {
		fmt.Printf("[ERROR] %s\n", err.Error())
	}
	var rowid = 1007
	var x1 = "<bool>false</bool>"
	testdb.Exec("delete GO_UNIT_Xml_DEAL where id = ?", rowid)
	testdb.Exec("INSERT INTO GO_UNIT_Xml_DEAL VALUES(?,?)", rowid, x1)
	var equalrow = testdb.QueryRow("select count(*) from GO_UNIT_Xml_DEAL where id = ? and x1 = ?;", rowid, x1)
	var row_count int32
	equalrow.Scan(&row_count)
	if row_count != 1 {
		t.Errorf("TestDbExec_Insert_Xml_interger FAIL.")
	}
	testdb.Close()
}
